@@ -171,3 +171,84 @@ TEST(table, iterator) {
     }
     ASSERT_EQ(count, _ptr->count());
 }
+
+static int test_table_size = 128;
+
+static void create_table(table_t &table) {
+    auto ptr = table.ptr();
+    ptr->set_hash_func([](const char *key, size_t len) -> uint64_t { return 1; });
+
+    ASSERT_TRUE(table.set("php", {"php", 1, 1.245}));
+    ASSERT_TRUE(table.set("java", {"java", 2, 3.1415926}));
+    ASSERT_TRUE(table.set("c++", {"c++", 3, 4.888}));
+    ASSERT_TRUE(table.set("js", {"js", 9, 6565}));
+    ASSERT_TRUE(table.set("golang", {"golang", 4, 9.888}));
+}
+
+TEST(table, conflict1) {
+    table_t table(test_table_size);
+    ASSERT_FALSE(table.exists("swift"));
+
+    create_table(table);
+    auto ptr = table.ptr();
+
+    ASSERT_FALSE(table.exists("kotlin"));
+
+    ASSERT_TRUE(table.del("php"));
+    ASSERT_FALSE(table.exists("php"));
+    ASSERT_TRUE(table.set("rust", {"rust", 5, 9.888}));
+
+    ASSERT_TRUE(table.del("golang"));
+    ASSERT_FALSE(table.exists("golang"));
+    ASSERT_TRUE(table.set("erlang", {"erlang", 6, 12.888}));
+
+    ASSERT_TRUE(table.del("java"));
+    ASSERT_FALSE(table.exists("java"));
+
+    ASSERT_EQ(ptr->get_total_slice_num() - ptr->get_available_slice_num(), table.count() - 1);
+}
+
+TEST(table, conflict2) {
+    table_t table(test_table_size);
+    create_table(table);
+    auto ptr = table.ptr();
+
+    ASSERT_TRUE(table.del("java"));
+    ASSERT_FALSE(table.exists("java"));
+    ASSERT_TRUE(table.set("rust", {"rust", 5, 9.888}));
+
+    ASSERT_TRUE(table.del("golang"));
+    ASSERT_FALSE(table.exists("golang"));
+    ASSERT_TRUE(table.set("erlang", {"erlang", 6, 12.888}));
+
+    ASSERT_EQ(ptr->get_total_slice_num() - ptr->get_available_slice_num(), table.count() - 1);
+}
+
+TEST(table, conflict3) {
+    table_t table(test_table_size);
+    create_table(table);
+    auto ptr = table.ptr();
+
+    ASSERT_TRUE(table.del("golang"));
+    ASSERT_TRUE(table.set("erlang", {"erlang", 6, 12.888}));
+
+    ASSERT_TRUE(table.del("java"));
+
+    ASSERT_EQ(ptr->get_total_slice_num() - ptr->get_available_slice_num(), table.count() - 1);
+}
+
+TEST(table, conflict4) {
+    table_t table(test_table_size);
+    create_table(table);
+    auto ptr = table.ptr();
+
+    ASSERT_TRUE(table.del("c++"));
+    ASSERT_TRUE(table.set("rust", {"rust", 5, 9.888}));
+
+    ASSERT_TRUE(table.del("golang"));
+    ASSERT_TRUE(table.set("erlang", {"erlang", 6, 12.888}));
+
+    ASSERT_TRUE(table.del("java"));
+
+    ASSERT_EQ(ptr->get_total_slice_num() - ptr->get_available_slice_num(), table.count() - 1);
+}
