@@ -89,6 +89,7 @@ class PHPCoroutine {
 
     struct Config {
         uint64_t max_num;
+        uint32_t max_concurrency;
         uint32_t hook_flags;
         bool enable_preemptive_scheduler;
         bool enable_deadlock_check;
@@ -204,6 +205,10 @@ class PHPCoroutine {
         config.enable_preemptive_scheduler = value;
     }
 
+    static inline void set_max_concurrency(uint32_t value) {
+        config.max_concurrency = value;
+    }
+
     static inline bool is_activated() {
         return activated;
     }
@@ -212,6 +217,7 @@ class PHPCoroutine {
     static bool activated;
     static PHPContext main_task;
     static Config config;
+    static uint32_t concurrency;
 
     static bool interrupt_thread_running;
     static std::thread interrupt_thread;
