@@ -151,7 +151,7 @@ static inline bool decode(Frame *frame, String *str) {
     return decode(frame, str->str, str->length);
 }
 
-ssize_t get_package_length(Protocol *protocol, network::Socket *conn, const char *data, uint32_t length);
+ssize_t get_package_length(const Protocol *protocol, network::Socket *conn, PacketLength *pl);
 int dispatch_frame(const Protocol *protocol, network::Socket *conn, const RecvData *rdata);
 
 }  // namespace websocket
