@@ -22,7 +22,7 @@ namespace swoole {
 struct FixedPoolSlice {
     uint8_t lock;
     FixedPoolSlice *next;
-    FixedPoolSlice *pre;
+    FixedPoolSlice *prev;
     char data[0];
 };
 
@@ -79,8 +79,8 @@ FixedPool::FixedPool(uint32_t slice_num, uint32_t slice_size, bool shared) {
  * create new FixedPool, Using the given memory
  */
 FixedPool::FixedPool(uint32_t slice_size, void *memory, size_t size, bool shared) {
-    impl = (FixedPoolImpl*) memory;
-    memory = (char*) memory + sizeof(*impl);
+    impl = (FixedPoolImpl *) memory;
+    memory = (char *) memory + sizeof(*impl);
     sw_memset_zero(impl, sizeof(*impl));
     impl->shared = shared;
     impl->slice_size = slice_size;
@@ -115,7 +115,7 @@ void FixedPoolImpl::init() {
         sw_memset_zero(slice, sizeof(FixedPoolSlice));
 
         if (head != nullptr) {
-            head->pre = slice;
+            head->prev = slice;
             slice->next = head;
         } else {
             tail = slice;
@@ -125,9 +125,9 @@ void FixedPoolImpl::init() {
         cur = (char *) cur + (sizeof(FixedPoolSlice) + slice_size);
 
         if (cur < max) {
-            slice->pre = (FixedPoolSlice *) cur;
+            slice->prev = (FixedPoolSlice *) cur;
         } else {
-            slice->pre = nullptr;
+            slice->prev = nullptr;
             break;
         }
 
@@ -147,64 +147,53 @@ uint32_t FixedPool::get_slice_size() {
 }
 
 void *FixedPool::alloc(uint32_t size) {
-    FixedPoolSlice *slice;
-
-    slice = impl->head;
-
-    if (slice->lock == 0) {
-        slice->lock = 1;
-        impl->slice_use++;
-        /**
-         * move next slice to head (idle list)
-         */
-        impl->head = slice->next;
-        slice->next->pre = nullptr;
-
-        /*
-         * move this slice to tail (busy list)
-         */
-        impl->tail->next = slice;
-        slice->next = nullptr;
-        slice->pre = impl->tail;
-        impl->tail = slice;
-
-        return slice->data;
-    } else {
+    FixedPoolSlice *slice = impl->head;
+    if (slice->lock) {
+        swoole_set_last_error(SW_ERROR_MALLOC_FAIL);
         return nullptr;
     }
+
+    slice->lock = 1;
+    impl->slice_use++;
+
+    // move next slice to head (idle list)
+    impl->head = slice->next;
+    impl->head->prev = nullptr;
+
+    // move this slice to tail (busy list)
+    impl->tail->next = slice;
+    slice->next = nullptr;
+    slice->prev = impl->tail;
+    impl->tail = slice;
+
+    return slice->data;
 }
 
 void FixedPool::free(void *ptr) {
-    FixedPoolSlice *slice;
+    FixedPoolSlice *slice = (FixedPoolSlice *) ((char *) ptr - sizeof(FixedPoolSlice));
 
     assert(ptr > impl->memory && (char *) ptr < (char *) impl->memory + impl->size);
+    assert(slice->lock == 1);
 
-    slice = (FixedPoolSlice *) ((char *) ptr - sizeof(FixedPoolSlice));
-
-    if (slice->lock) {
-        impl->slice_use--;
-    }
-
+    impl->slice_use--;
     slice->lock = 0;
 
-    // list head, AB
-    if (slice->pre == nullptr) {
+    if (slice == impl->head) {
         return;
     }
-    // list tail, DE
-    if (slice->next == nullptr) {
-        slice->pre->next = nullptr;
-        impl->tail = slice->pre;
-    }
-    // middle BCD
-    else {
-        slice->pre->next = slice->next;
-        slice->next->pre = slice->pre;
+
+    if (slice == impl->tail) {
+        slice->prev->next = nullptr;
+        impl->tail = slice->prev;
+    } else {
+        slice->prev->next = slice->next;
+        slice->next->prev = slice->prev;
     }
 
-    slice->pre = nullptr;
+    // move slice to head (idle)
+    slice->prev = nullptr;
     slice->next = impl->head;
-    impl->head->pre = slice;
+    impl->head->prev = slice;
     impl->head = slice;
 }
 
@@ -219,7 +208,7 @@ FixedPool::~FixedPool() {
     }
 }
 
-void FixedPool::debug() {
+void FixedPool::debug(int max_lines) {
     int line = 0;
     FixedPoolSlice *slice = impl->head;
 
@@ -230,16 +219,17 @@ void FixedPool::debug() {
         }
 
         printf("#%d\t", line);
-        printf("Slab[%p]\t", slice);
-        printf("pre=%p\t", slice->pre);
+        printf("slice[%p]\t", slice);
+        printf("prev=%p\t", slice->prev);
         printf("next=%p\t", slice->next);
         printf("tag=%d\t", slice->lock);
         printf("data=%p\n", slice->data);
 
         slice = slice->next;
-        line++;
-        if (line > 100) break;
+        if (line++ > max_lines) {
+            break;
+        }
     }
 }
 
-}
+}  // namespace swoole
