@@ -59,7 +59,7 @@ ssize_t SocketPair::read(void *data, size_t length) {
 
 ssize_t SocketPair::write(const void *data, size_t length) {
     ssize_t n = master_socket->write(data, length);
-    if (blocking && n < 0 && timeout > 0 && master_socket->catch_error(errno) == SW_WAIT) {
+    if (blocking && n < 0 && timeout > 0 && master_socket->catch_write_error(errno) == SW_WAIT) {
         if (master_socket->wait_event(timeout * 1000, SW_EVENT_READ) < 0) {
             return SW_ERR;
         }
