@@ -1492,6 +1492,13 @@ bool Server::sendfile(SessionId session_id, const char *file, uint32_t l_file, o
         swoole_error_log(SW_LOG_WARNING, SW_ERROR_SYSTEM_CALL_FAIL, "stat(%s) failed", req->filename);
         return false;
     }
+    if (!S_ISREG(file_stat.st_mode)) {
+        swoole_error_log(SW_LOG_WARNING,
+                         SW_ERROR_SERVER_IS_NOT_REGULAR_FILE,
+                         "the path[%s] given is not a regular file",
+                         req->filename);
+        return false;
+    }
     if (file_stat.st_size <= offset) {
         swoole_error_log(SW_LOG_WARNING, SW_ERROR_SYSTEM_CALL_FAIL, "file[offset=%ld] is empty", (long) offset);
         return false;
@@ -1957,7 +1964,7 @@ _find_available_slot:
 }
 
 void Server::init_ipc_max_size() {
-#ifdef HAVE_KQUEUE
+#ifndef __linux__
     ipc_max_size = SW_IPC_MAX_SIZE;
 #else
     int bufsize;
@@ -1967,7 +1974,7 @@ void Server::init_ipc_max_size() {
     if (workers[0].pipe_master->get_option(SOL_SOCKET, SO_SNDBUF, &bufsize) != 0) {
         bufsize = SW_IPC_MAX_SIZE;
     }
-    ipc_max_size = bufsize - SW_DGRAM_HEADER_SIZE;
+    ipc_max_size = SW_MIN(bufsize, SW_IPC_BUFFER_MAX_SIZE) - SW_DGRAM_HEADER_SIZE;
 #endif
 }
 
