@@ -367,7 +367,7 @@ int Server::reply_task_result(const char *data, size_t data_len, int flags, Even
         while (1) {
             ret = pipe->write(&flag, sizeof(flag));
             auto _sock = pipe->get_socket(true);
-            if (ret < 0 && _sock->catch_error(errno) == SW_WAIT) {
+            if (ret < 0 && _sock->catch_write_error(errno) == SW_WAIT) {
                 if (_sock->wait_event(-1, SW_EVENT_WRITE) == 0) {
                     continue;
                 }
